# Change log

Release notes are maintained as part of the documentation:

* [sources here](docs/src/release_notes);
* [compiled documentation here](https://eradiate.readthedocs.io/en/latest/src/release_notes/index.html) (latest version).
